//
//  SCAdSequencingDelegate.h
//  SCMobileSDK
//
//  Copyright © 2018 smartclip Holding AG. All rights reserved.
//

#import <Foundation/Foundation.h>

@class SCAdSequencingController;
@class SCAdVariants;
@class SCAdConfiguration;

/**
 Delegate methods that are required to synchronise advertising video clips with
 clients custom content video player. Through this delegate the sequencing
 controller will provide information when to start and stop the content video player.
 */
@protocol SCAdSequencingDelegate <NSObject>
@optional
/**
 *Optional*

 This delegate method is called to provide information about Variant videos.
 These are typically short video jingles that are played before, in between or after your
 advertising blocks.

 - Parameter position: The position of the advertising block in sequence map to provide Variant information for.
 - Parameter controller: The target sequencing controller.

 - Returns: The Variant object taht carries information about opener, prebumper or closer ad urls. Look up SCAdVariants reference about further information.
 */
- (SCAdVariants*)addVariantsAt:(NSInteger)position controller:(SCAdSequencingController*)controller;


/**
 *Optional*

 Called to be able to edit the configuration at a given sequence position.
 - Parameter configuration: The default configuration for this position
 - Parameter position: The sequence position
 */
- (void)editConfiguration:(SCAdConfiguration*)configuration at:(NSInteger)position;

@required
/**
 *Required*

 Use this delegate method to provide the current playback position of a content
 video player to the sequencing controller. When there is an advertising clip for the
 given position in the sequence map the clip gets started and pauseContentVideoPlayer
 will be called.

 - Parameter controller: The target sequencing controller

 - Returns: The position of your content video player.
 */
- (NSInteger)getContentVideoPlayerPosition:(SCAdSequencingController*)controller;

/**
 *Required*

 Called when the sequencing player wants to play an advertising clip
 Implement code that causes your content video player to stop.

 - Parameter controller: The target sequencing controller
 */
- (void)pauseContentVideoPlayer:(SCAdSequencingController*)controller;

/**
 *Required*

 Called when an advertising clip from sequence stopped. Implement code
 that causes your content video player to continue.

 - Parameter controller: The target sequencing controller
 */
- (void)playContentVideoPlayer:(SCAdSequencingController*)controller;
@end
